@@ -1,4 +1,4 @@
-# copyright 2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2011-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -99,7 +99,7 @@ class PatchReviewBehaviour(EntityAdapter):
             'WHERE P eid %(p)s, '
             '      P patch_revision RE, '
             '      NOT P created_by U, '
-            '      EXISTS(U in_group G, G name "reviewers") '
+            '      EXISTS(R use_global_groups TRUE, U in_group G, G name "reviewers") '
             '      OR EXISTS(RE from_repository R, '
             '                R repository_reviewer U)',
             {'p': self.entity.eid})
