@@ -48,7 +48,7 @@ class PatchStatusChangeView(StatusChangeMixIn, NotificationView):
 
         context['patch'] = ''
         if self._kwargs['current_state'] == 'pending-review':
-            patch = entity.tip().export()
+            patch = entity.tip().export().decode(entity.repository.encoding, 'replace')
             if len(patch) > MAX_PATCH_SIZE:
                 patch = patch[:MAX_PATCH_SIZE] + '\n@@ truncated patch @@'
             context['patch'] = patch
@@ -104,7 +104,7 @@ url: %(url)s
     def context(self, **kwargs):
         context = super(ReviewerSetNotificationView, self).context(**kwargs)
         entity = self.cw_rset.get_entity(0, 0)
-        patch = entity.tip().export()
+        patch = entity.tip().export().decode(entity.repository.encoding, 'replace')
         if len(patch) > MAX_PATCH_SIZE:
             patch = patch[:MAX_PATCH_SIZE] + '\n@@ truncated patch @@'
         context['patch'] = patch
