@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 # copyright 2011-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
@@ -536,7 +538,7 @@ class PatchNotificationTC(CubicWebTC):
         got = email.content.splitlines()
         # we should print a diff like -/+ stuff
         for idx, line in enumerate(expected):
-            self.assertMatches(line, got[idx])
+            self.assertMatches('^' + line + '$', got[idx])
         self.assertEqual(len(expected), len(got))
 
     def assertMatches(self, expected, got):
@@ -561,7 +563,7 @@ class PatchNotificationTC(CubicWebTC):
     def test_reviewer_email(self):
         session = self.session
         rql = 'Any R ORDERBY R DESC WHERE R is Revision'
-        rev = session.execute(rql).get_entity(0, 0)
+        rev = session.execute(rql).get_entity(1, 0)
         assert rev.description == 'Add more elephants children'
         patch = rev.reverse_patch_revision[0]
         assert patch.patch_name == 'Add more elephants children'
@@ -636,7 +638,7 @@ class PatchNotificationTC(CubicWebTC):
         # reask review
         MAILBOX[:] = ()
         patch.cw_adapt_to('IWorkflowable').fire_transition('ask rework',
-                                                           u'tasked')
+                                                           u'tasked ø')
         session.commit(free_cnxset=False)
         self.assertEqual(2, len(MAILBOX))
         MAILBOX.sort(key=lambda e: 'victor@ratax.es' in e.recipients)
@@ -648,7 +650,7 @@ class PatchNotificationTC(CubicWebTC):
                               'admin changed status from <pending-review> to <in-progress> for entity\n'
                               "'Add more elephants children'\n"
                               '\n'
-                              'tasked\n'
+                              u'tasked ø\n'
                               '\n'
                               'remaining tasks:\n'
                               '\n'
@@ -677,6 +679,22 @@ class PatchNotificationTC(CubicWebTC):
                               'i18n_by_author_field: admin\n'
                               'url: http://testing.fr/cubicweb/task/%i' % task.eid)
 
+    def test_nonascii(self):
+        session = self.session
+        rql = 'Any R ORDERBY R DESC WHERE R is Revision'
+        rev = session.execute(rql).get_entity(0, 0)
+        patch = rev.reverse_patch_revision[0]
+        patch.cw_adapt_to('IWorkflowable').fire_transition('ask rework',
+                                                           u'coin coin')
+        session.commit(free_cnxset=False)
+        self.assertEqual(2, len(MAILBOX))
+
+        MAILBOX[:] = []
+        # patch are only send on ask review, so we reask for review
+        patch.cw_adapt_to('IWorkflowable').fire_transition('ask review',
+                                                           u'coin coin')
+        session.commit(free_cnxset=False)
+        self.assertEqual(2, len(MAILBOX))
 
 PatchNotificationTC.repo_path = osp.join(PatchNotificationTC.datadir,
                                          u'demo-repo-final')
