@@ -24,6 +24,7 @@ from cubicweb.selectors import (is_instance, relation_possible,
                                 score_entity, match_form_params)
 from cubicweb import tags, uilib, view
 from cubicweb.web import uicfg, component, form, formwidgets as wdg
+from cubicweb.view import EntityView
 from cubicweb.web.views import (workflow, idownloadable, ajaxedit,
                                 forms, formrenderers)
 
@@ -109,14 +110,71 @@ class ActivityComponent(component.EntityCtxComponent):
         rset = self._cw.execute(self.existing_tasks_rql, {'x': self.entity.eid})
         if rset:
             w(u'<h4>%s</h4>' % self._cw._('Activities'))
-            self._cw.view('editable-table', rset, w=w,
-                          headers=[self._cw.__('Task_plural'),
-                                   self._cw._('detail'),
-                                   self._cw.__('in_state'),
-                                   self._cw.__('creation_date'),
-                                   self._cw.__('created_by'),],
-                          cellvids={0: 'vcreview.task-link',
-                                    2: 'vcreview.task-state'})
+            self._cw.view('vcreview.task-view', rset, w=w)
+class TaskView(EntityView):
+    """a component to display an html section displaying activities related to
+    an object
+    """
+    __regid__ = 'vcreview.task-view'
+    __select__ = EntityView.__select__ & is_instance('Task')
+
+    def cell_call(self, row, col):
+        self._cw.add_css('cubes.vcreview.css')
+        assert col == 0
+        task = self.cw_rset.get_entity(row, col)
+        iwf  = task.cw_adapt_to('IWorkflowable')
+        assert iwf.state in ('todo', 'done'), iwf.state
+        self.w(u'<div class="vcreview_task task_%s">' % iwf.state)
+        self.w(u'<h5>')
+        self.w(u'<span class="vcreview_taskstate">')
+        self.w(iwf.printable_state)
+        self.w(u'</span>')
+        self.w(u'<span class="vcreview_tasktitle">')
+        self.wview(u'vcreview.task-link', rset=self.cw_rset, row=row, col=col)
+        self.w(u'</span>')
+        if self._can_mark_as_done(iwf):
+            url = self._mark_as_done_callback(task.eid)
+            self.w(tags.input(type='button', onclick=url,
+                              value='mark as done', klass="task_is_done"))
+        self.w(u'</h5>')
+        self.w(u'<p class="vcreview_taskinfo">Created ')
+        self.w(task.printable_value('creation_date'))
+        if task.created_by:
+            self.w(u' by ')
+            self.wview(u'incontext', rset=task.created_by[0].as_rset())
+        self.w(u'</p>')
+        self.w(u'<div id="vcreview_taskdescription">')
+        self.w(task.view('reledit', rtype='description'))
+        self.w(u'</div>')
+
+        self.w(u'<div id="navcontentbottom%s">' % task.eid)
+        comp = self._cw.vreg['ctxcomponents'].select_or_none('commentsection',
+            self._cw,
+            rset=task.as_rset(),
+            entity=task,
+            context='navcontentbottom',
+            __cache=None)
+        if comp is not None:
+            comp.render(w=self.w)
+        self.w(u'</div>')
+
+        self.w(u'</div>')
+
+    @staticmethod
+    def _can_mark_as_done(iwf):
+        if iwf.state != 'todo':
+            return False
+        for transition in iwf.possible_transitions():
+            if transition.name == 'done':
+                return True
+        else:
+            return False # task workflow changed or no permission to go through the transition
+
+    def _mark_as_done_callback(self, eid):
+        def change_state(req, eid):
+            entity = req.entity_from_eid(eid)
+            entity.cw_adapt_to('IWorkflowable').fire_transition('done')
+        return self._cw.user_callback(change_state, (eid,))
 
 
 class PatchActivityComponent(ActivityComponent):
@@ -143,26 +201,6 @@ ActivityComponent.order = 20
 comment.CommentSectionVComponent.order = 30
 
 
-class TaskStateView(form.FormViewMixIn, view.EntityView):
-    __regid__ = 'vcreview.task-state'
-    __select__ = is_instance('Task')
-
-    def entity_call(self, entity):
-        self._cw.add_css('cubes.vcreview.css')
-        iwf = entity.cw_adapt_to('IWorkflowable')
-        self.w(iwf.printable_state)
-        if iwf.state != 'todo':
-            return
-        for transition in iwf.possible_transitions():
-            if transition.name == 'done':
-                break
-        else:
-            return # task workflow changed or no permission to go through the transition
-        def change_state(req, eid):
-            entity = req.entity_from_eid(eid)
-            entity.cw_adapt_to('IWorkflowable').fire_transition('done')
-        url = self._cw.user_callback(change_state, (entity.eid,))
-        self.w(tags.input(type='button', onclick=url, value=self._cw._('mark as done')))
 
 
 class TaskLinkView(form.FormViewMixIn, view.EntityView):
