@@ -1,4 +1,4 @@
-# copyright 2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2011-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -74,11 +74,11 @@ class UserWorkList(AllActivePatches):
            '      EXISTS(PS name "pending-review" AND P patch_reviewer U) '
            # Patch is reviewed  and CWUser is commiter
            '      OR EXISTS(PS name "reviewed" AND P patch_committer U) '
-           # Patch is reviewed  and CWUser repository or global commiter 
+           # Patch is reviewed  and CWUser repository or global commiter
            '      OR (EXISTS(PS name "reviewed"'
            '          AND NOT EXISTS(P patch_committer V) '
            '          AND (EXISTS(R repository_committer U)'
-           '              OR EXISTS(U in_group G, G name "committers"))))')
+           '              OR EXISTS(R use_global_groups TRUE, U in_group G, G name "committers"))))')
 
     @cached
     def filter_box_context_info(self):
